document.addEventListener('DOMContentLoaded', () => {
    let images = document.querySelectorAll('section article img');
    let lightbox = document.createElement('div');
    let imgWrapper = document.createElement('div');
    let img = document.createElement('img');
    let arrowRight = document.createElement('button');
    let arrowLeft = document.createElement('button');
    let sizeOverlay = document.createElement('div');
    let toggleButton = document.createElement('button');
    let controlsContainer = document.createElement('div'); // New control container
    let imgArray = Array.from(images);
    let currentIndex = 0;

    lightbox.className = 'lightbox';
    imgWrapper.className = 'img-wrapper';
    arrowRight.className = 'arrow right';
    arrowLeft.className = 'arrow left';
    sizeOverlay.className = 'size-overlay';
    toggleButton.className = 'toggle-button';
    controlsContainer.className = 'controls-container'; // Assigning class
    
    arrowRight.innerHTML = '>';
    arrowLeft.innerHTML = '<';
    toggleButton.innerHTML = 'display original';
    
    document.body.appendChild(lightbox);
    lightbox.appendChild(imgWrapper);
    imgWrapper.appendChild(img);
    
    // Appending controls to controls-container and the container to imgWrapper
    controlsContainer.appendChild(toggleButton);
    controlsContainer.appendChild(sizeOverlay);
    imgWrapper.appendChild(controlsContainer);
    
    lightbox.appendChild(arrowRight);
    lightbox.appendChild(arrowLeft);

    imgArray.forEach((image, index) => {
        image.addEventListener('click', () => {
            lightbox.style.display = 'flex';
            img.src = image.src;
            img.dataset.hires = image.dataset.hires;
            sizeOverlay.innerText = image.getAttribute('data-size') || 'Size not available';
            currentIndex = index;
        });
    });

    lightbox.addEventListener('click', (e) => {
        if (e.target !== toggleButton && e.target !== arrowRight && e.target !== arrowLeft) {
            lightbox.style.display = 'none';
        }
    });

    toggleButton.addEventListener('click', () => {
        let tempSrc = img.src;
        img.src = img.dataset.hires;
        img.dataset.hires = tempSrc;
        toggleButton.innerText = toggleButton.innerText === "display original" ? "display dithered" : "display original";
    });

    function updateSizeOverlay() {
        sizeOverlay.innerText = imgArray[currentIndex].getAttribute('data-size') || 'Size not available';
        img.dataset.hires = imgArray[currentIndex].dataset.hires;
    }

    arrowRight.addEventListener('click', () => {
        currentIndex = (currentIndex + 1) % imgArray.length;
        img.src = imgArray[currentIndex].src;
        updateSizeOverlay();
    });

    arrowLeft.addEventListener('click', () => {
        currentIndex = (currentIndex - 1 + imgArray.length) % imgArray.length;
        img.src = imgArray[currentIndex].src;
        updateSizeOverlay();
    });

    document.addEventListener('keydown', (e) => {
        if (lightbox.style.display === 'flex') {
            if (e.key === 'ArrowRight') {
                arrowRight.click();
            } else if (e.key === 'ArrowLeft') {
                arrowLeft.click();
            } else if (e.key === 'Escape') {
                lightbox.style.display = 'none';
            }
        }
    });
});



document.addEventListener("DOMContentLoaded", function() {
    // Fetch all the articles
    let articles = document.querySelectorAll('article');
  
    let sentences = [];
  
    // Loop through each article to get its sentences and associated time
    articles.forEach(function(article) {
      let timeElement = article.querySelector('time');
      let paragraph = article.querySelector('p');
      
      if (timeElement && paragraph) {
        // Split the text content into sentences
        let articleSentences = paragraph.innerText.match(/[^.!?]+[.!?]+/g) || []; // Fallback to an empty array if no matches are found
        
        articleSentences.forEach(sentence => {
          sentences.push({
            time: timeElement.innerText,
            text: sentence.trim() // Trim to remove any leading/trailing whitespace
          });
        });
      }
    });
  
    // Function to 'type out' text
    function typeText(entry) {
      let container = document.querySelector('#quote');
      let quoteInner = document.querySelector('#quote-inner');
      
      // Clear the current content
      if (quoteInner) {
        quoteInner.innerText = '';
      } else {
        quoteInner = document.createElement('span');
        quoteInner.id = 'quote-inner';
        container.appendChild(quoteInner);
      }
  
      // Set the time content
      let timeElement = container.querySelector('time');
      if (!timeElement) {
        timeElement = document.createElement('time');
        container.insertBefore(timeElement, quoteInner);
      }
      timeElement.innerText = entry.time;
  
      // 'Type out' the text
      let index = 0;
      let tempText = ''; // Temporary holder for the text being typed
      function type() {
        if (index < entry.text.length) {
          tempText += entry.text[index]; // Add character to temporary string
          quoteInner.innerText = tempText; // Update the inner text of the span
          index++;
          setTimeout(type, 100); // typing speed
        }
      }
      type();
    }
  
    // Get a random sentence
    let randomSentence = sentences[Math.floor(Math.random() * sentences.length)];
  
    // Call the typeText function with the random sentence
    typeText(randomSentence);
  });
  

  
  
  
  
